==> xl-react-components-0.18.103.tgz: package/app/xl-react-widget/xl-react-widget-tags/suggestion-behavior/skin-suggestion-behavior.js <==
import R from 'ramda';
import React from 'react';
import classNames from 'classnames';
import {transformItem, transformItemOr} from '../../../utils/transform-utils';
import RU from '../../../utils/ramda-utils';
import {reasonTypeOfAddingCandidate} from '../../xl-react-widget-autocomplete/reason-type-of-adding-candidate';
import {tagsAutocompleteSkins} from '../xl-react-widget-tags-skins';
import {focusWithTimeout, shouldGetSuggestions} from '../../../utils/behaviour-utils';

const renderColoredElement = (className, color) => <i className={className} style={{backgroundColor: color}}/>;
const renderColoredSuggestion = (color) => renderColoredElement('suggested-tag', color);
const renderColoredOption = (color) => renderColoredElement('option-icon', color);
const shouldRenderColoredSuggestion = (withColor, color) => withColor ? renderColoredSuggestion(color) : '';
const shouldRenderColoredOption = (withColor, color) => withColor ? renderColoredOption(color) : '';

const renderOption = (optionData, objLabel, value, isSkinWithColor) => {
    const optionItem = transformItem(optionData, objLabel);
    const valueItem = transformItemOr('', value, objLabel);

    const checked = RU.isTrue(['checked'], optionData);
    const index = R.toLower(optionItem).indexOf(R.toLower(valueItem));
    if (R.gt(index, -1)) {
        return <span>
            <div>
                <input checked={checked} readOnly={true} type="checkbox"/>
                <i className={classNames('checkbox', {checked})} data={optionItem}/>
                {shouldRenderColoredSuggestion(isSkinWithColor, optionData.color)}
                {optionItem.slice(0, index)}
                <strong>{optionItem.slice(index, index + value.length)}</strong>
                {optionItem.slice(index + value.length)}
            </div>
        </span>;
    }

    return <span>
        <div>
            <input checked={checked} readOnly={true} type="checkbox"/>
            <i className={classNames('checkbox', {checked})} data={optionItem}/>
            {shouldRenderColoredSuggestion(isSkinWithColor, optionData.color)}
            {optionItem}
        </div>
    </span>;
};

export const getSkinBehavior = (isSkinWithColor) => {
    const behavior = {
        handleOnFocus: R.curry((component, event) => {
            const {handleGetSuggestions, inputProps, model} = component.props;
            if (shouldGetSuggestions(component)) {
                handleGetSuggestions(model, reasonTypeOfAddingCandidate.onInputFocus);
            }
            component.setState({isCollapsed: false, isFocused: true});
            RU.invoke('onFocus', [event], inputProps);
        }),
        handleOnSuggestionClick: R.curry((component, event, suggestion) => {
            const {handleGetSuggestions, handleSuggestionSelected, model, objLabel} = component.props;
            const newValue = !R.is(Object, model) ? transformItem(suggestion, objLabel) : suggestion;
            handleSuggestionSelected(event, {suggestion}, [() => {
                handleGetSuggestions(model, reasonTypeOfAddingCandidate.onSuggestionClick);
            }]);
            component.notifyOnChange(event, newValue);
            component.setState({inputValue: ''});
            focusWithTimeout(component, event, behavior);
        }),
        renderSuggestion: R.curry((component, data, value) => {
            const {objLabel} = component.props;
            return <div className="yt-option" title={transformItem(data, objLabel)}>
                {renderOption(data, objLabel, value, isSkinWithColor)}
            </div>;
        }),
        renderTag: R.curry((component, renderProps) => {
            const {
                tag, key, disabled, onRemove, classNameRemove, ...others
            } = R.omit(['getTagDisplayValue'], renderProps);

            const highlightClass = classNames({
                'highlighted': component.props.tag === tag,
                'react-tagsinput-tag': true
            });
            const handleClick = () => onRemove(key);
            return <span
                key={key} {...others}
                className={highlightClass}
                title={tag.value}>
                {shouldRenderColoredOption(isSkinWithColor, tag.color)}
                {tag.label}
                {!disabled && <a className={classNameRemove} onMouseDown={handleClick}/>}
            </span>;
        })
    };

    return behavior;
};

export const checkboxSuggestionBehavior = {
    ...getSkinBehavior(false),
    isMatched: (skin) => skin === tagsAutocompleteSkins.CHECKBOX
};

export const colorAndCheckboxSuggestionBehavior = {
    ...getSkinBehavior(true),
    isMatched: (skin) => skin === tagsAutocompleteSkins.COLOR_AND_CHECKBOX
};

==> xl-react-components-0.21.15.tgz: package/app/xl-react-widget/xl-react-widget-tags/suggestion-behavior/skin-suggestion-behavior.js <==
import R from 'ramda';
import React from 'react';
import classNames from 'classnames';
import {transformItem, transformItemOr} from '../../../utils/transform-utils';
import RU from '../../../utils/ramda-utils';
import {reasonTypeOfAddingCandidate} from '../../xl-react-widget-autocomplete/reason-type-of-adding-candidate';
import {tagsAutocompleteSkins} from '../xl-react-widget-tags-skins';
import {focusWithTimeout, shouldGetSuggestions} from '../../../utils/behaviour-utils';

const renderColoredElement = (className, color) => <i className={className} style={{backgroundColor: color}}/>;
const renderColoredSuggestion = (color) => renderColoredElement('suggested-tag', color);
const renderColoredOption = (color) => renderColoredElement('option-icon', color);
const shouldRenderColoredSuggestion = (withColor, color) => withColor ? renderColoredSuggestion(color) : '';
const shouldRenderColoredOption = (withColor, color) => withColor ? renderColoredOption(color) : '';

const renderOption = (optionData, objLabel, value, isSkinWithColor) => {
    const optionItem = transformItem(optionData, objLabel);
    const valueItem = transformItemOr('', value, objLabel);

    const checked = RU.isTrue(['checked'], optionData);
    const index = R.toLower(optionItem).indexOf(R.toLower(valueItem));
    if (R.gt(index, -1)) {
        return <span>
            <div>
                <input checked={checked} readOnly={true} type="checkbox"/>
                <i className={classNames('xl-icon icon-s checkbox', {'check-icon': checked})} data={optionItem}/>
                {shouldRenderColoredSuggestion(isSkinWithColor, optionData.color)}
                {optionItem.slice(0, index)}
                <strong>{optionItem.slice(index, index + value.length)}</strong>
                {optionItem.slice(index + value.length)}
            </div>
        </span>;
    }

    return <span>
        <div>
            <input checked={checked} readOnly={true} type="checkbox"/>
            <i className={classNames('xl-icon icon-s checkbox', {'check-icon': checked})} data={optionItem}/>
            {shouldRenderColoredSuggestion(isSkinWithColor, optionData.color)}
            {optionItem}
        </div>
    </span>;
};

export const getSkinBehavior = (isSkinWithColor) => {
    const behavior = {
        handleOnFocus: R.curry((component, event) => {
            const {handleGetSuggestions, inputProps, model} = component.props;
            if (shouldGetSuggestions(component)) {
                handleGetSuggestions(model, reasonTypeOfAddingCandidate.onInputFocus);
            }
            component.setState({isCollapsed: false, isFocused: true});
            RU.invoke('onFocus', [event], inputProps);
        }),
        handleOnSuggestionClick: R.curry((component, event, suggestion) => {
            const {handleGetSuggestions, handleSuggestionSelected, model, objLabel} = component.props;
            const newValue = !R.is(Object, model) ? transformItem(suggestion, objLabel) : suggestion;
            handleSuggestionSelected(event, {suggestion}, [() => {
                handleGetSuggestions(model, reasonTypeOfAddingCandidate.onSuggestionClick);
            }]);
            component.notifyOnChange(event, newValue);
            component.setState({inputValue: ''});
            focusWithTimeout(component, event, behavior);
        }),
        renderSuggestion: R.curry((component, data, value) => {
            const {objLabel} = component.props;
            return <div className="yt-option" title={transformItem(data, objLabel)}>
                {renderOption(data, objLabel, value, isSkinWithColor)}
            </div>;
        }),
        renderTag: R.curry((component, renderProps) => {
            const {
                tag, key, disabled, onRemove, classNameRemove, ...others
            } = R.omit(['getTagDisplayValue'], renderProps);

            const highlightClass = classNames({
                'highlighted': component.props.tag === tag,
                'react-tagsinput-tag': true
            });
            const handleClick = () => onRemove(key);
            return <span
                key={key} {...others}
                className={highlightClass}
                title={tag.value}>
                {shouldRenderColoredOption(isSkinWithColor, tag.color)}
                {tag.label}
                {!disabled && <a className={classNameRemove} onMouseDown={handleClick}/>}
            </span>;
        })
    };

    return behavior;
};

export const checkboxSuggestionBehavior = {
    ...getSkinBehavior(false),
    isMatched: (skin) => skin === tagsAutocompleteSkins.CHECKBOX
};

export const colorAndCheckboxSuggestionBehavior = {
    ...getSkinBehavior(true),
    isMatched: (skin) => skin === tagsAutocompleteSkins.COLOR_AND_CHECKBOX
};
